# winsay
Say command in windows

```
say -h
usage: say [-h] [-i INPUT] [text [text ...]]

Say in windows

positional arguments:
  text                  sentence to speak

optional arguments:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
                        Text File to speak
```


### Back Story

Read the backstory for this project [here](https://sukhbinder.wordpress.com/2020/09/30/winsay/)

# Install
pip install winsay


# Demo

[![Check a demo](https://raw.githubusercontent.com/sukhbinder/winsay/master/img/youtube.png)](https://youtu.be/dZaV5MtG3n4)


